==> igniteui-webcomponents-core-3.2.4.tgz: package/esm5/lib/ImageCellInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CellInfoDescriptionMetadata } from "./CellInfoDescriptionMetadata";
import { ImageCellInfoDescription } from "./ImageCellInfoDescription";
/**
 * @hidden
 */
var ImageCellInfoDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ImageCellInfoDescriptionMetadata, _super);
    function ImageCellInfoDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ImageCellInfoDescriptionMetadata.b = function (a) {
        if (ImageCellInfoDescriptionMetadata.a == null) {
            ImageCellInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ImageCellInfoDescriptionMetadata.c(ImageCellInfoDescriptionMetadata.a);
        }
        if (a.g(ImageCellInfoDescriptionMetadata.a)) {
            return;
        }
        a.s(ImageCellInfoDescriptionMetadata.a);
    };
    ImageCellInfoDescriptionMetadata.c = function (a) {
        CellInfoDescriptionMetadata.c(a);
        a.item("ImagePath", "String");
        a.item("ImageStretchOption", "ExportedType:string:ImageStretchOptions");
        a.item("ImageStretchOption@names", "Uniform;Fill;None");
        a.item("ImageResourceType", "ExportedType:string:ImageResourceType");
        a.item("ImageResourceType@names", "Unspecified;LocalResource;LocalAsset;EmbeddedResource;RemoteResource");
    };
    ImageCellInfoDescriptionMetadata.d = function (a) {
        ImageCellInfoDescriptionMetadata.b(a);
        a.u("ImageCellInfo", function () { return new ImageCellInfoDescription(); });
        a.t("ImageCellInfo", ImageCellInfoDescriptionMetadata.a);
    };
    ImageCellInfoDescriptionMetadata.$t = markType(ImageCellInfoDescriptionMetadata, 'ImageCellInfoDescriptionMetadata');
    ImageCellInfoDescriptionMetadata.a = null;
    return ImageCellInfoDescriptionMetadata;
}(Base));
export { ImageCellInfoDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/ImageCellInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CellInfoDescriptionMetadata } from "./CellInfoDescriptionMetadata";
import { ImageCellInfoDescription } from "./ImageCellInfoDescription";
/**
 * @hidden
 */
var ImageCellInfoDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ImageCellInfoDescriptionMetadata, _super);
    function ImageCellInfoDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ImageCellInfoDescriptionMetadata.b = function (a) {
        if (ImageCellInfoDescriptionMetadata.a == null) {
            ImageCellInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ImageCellInfoDescriptionMetadata.c(ImageCellInfoDescriptionMetadata.a);
        }
        if (a.j(ImageCellInfoDescriptionMetadata.a)) {
            return;
        }
        a.y(ImageCellInfoDescriptionMetadata.a);
    };
    ImageCellInfoDescriptionMetadata.c = function (a) {
        CellInfoDescriptionMetadata.c(a);
        a.item("ImagePath", "String");
        a.item("ImageStretchOption", "ExportedType:string:ImageStretchOptions");
        a.item("ImageStretchOption@names", "Uniform;Fill;None");
        a.item("ImageResourceType", "ExportedType:string:ImageResourceType");
        a.item("ImageResourceType@names", "Unspecified;LocalResource;LocalAsset;EmbeddedResource;RemoteResource");
    };
    ImageCellInfoDescriptionMetadata.d = function (a) {
        ImageCellInfoDescriptionMetadata.b(a);
        a.aa("ImageCellInfo", function () { return new ImageCellInfoDescription(); });
        a.z("ImageCellInfo", ImageCellInfoDescriptionMetadata.a);
    };
    ImageCellInfoDescriptionMetadata.$t = markType(ImageCellInfoDescriptionMetadata, 'ImageCellInfoDescriptionMetadata');
    ImageCellInfoDescriptionMetadata.a = null;
    return ImageCellInfoDescriptionMetadata;
}(Base));
export { ImageCellInfoDescriptionMetadata };
